@@ -12,6 +12,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-__version__ = '0.1.0'
+__version__ = '0.1.1'
 
 from dwave.preprocessing import *
+import dwave.preprocessing.composites
+from dwave.preprocessing.composites import *
+import dwave.preprocessing.lower_bounds
+from dwave.preprocessing.lower_bounds import *
